aboutsummaryrefslogtreecommitdiff
path: root/engines/sci/seq_decoder.h
diff options
context:
space:
mode:
Diffstat (limited to 'engines/sci/seq_decoder.h')
-rw-r--r--engines/sci/seq_decoder.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/engines/sci/seq_decoder.h b/engines/sci/seq_decoder.h
index 30695ca0ff..7c810db05d 100644
--- a/engines/sci/seq_decoder.h
+++ b/engines/sci/seq_decoder.h
@@ -28,12 +28,12 @@
#include "graphics/video/video_player.h"
-namespace Graphics {
+namespace Sci {
/**
* Implementation of the Sierra SEQ decoder, used in KQ6 DOS floppy/CD and GK1 DOS
*/
-class SeqDecoder : public VideoDecoder {
+class SeqDecoder : public Graphics::VideoDecoder {
public:
SeqDecoder() {}
virtual ~SeqDecoder();
@@ -62,6 +62,6 @@ private:
bool decodeFrame(byte *rleData, int rleSize, byte *litData, int litSize, byte *dest, int left, int width, int height, int colorKey);
};
-} // End of namespace Graphics
+} // End of namespace Sci
#endif